@@ -43,18 +43,6 @@ class StartBack2BackCallRequest(RpcRequest):
 	def set_Broker(self,Broker):
 		self.add_query_param('Broker',Broker)
 
-	def get_UserId(self):
-		return self.get_query_params().get('UserId')
-
-	def set_UserId(self,UserId):
-		self.add_query_param('UserId',UserId)
-
-	def get_DeviceId(self):
-		return self.get_query_params().get('DeviceId')
-
-	def set_DeviceId(self,DeviceId):
-		self.add_query_param('DeviceId',DeviceId)
-
 	def get_AdditionalBroker(self):
 		return self.get_query_params().get('AdditionalBroker')
 
